@@ -20,11 +20,11 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Dialog.h>
+#include <Lum/Dlg/ActionDialog.h>
 
 #include "Package.h"
 
-class PackageDetails : public Lum::Dialog
+class PackageDetails : public Lum::Dlg::ActionDialog
 {
 private:
   Package&                package;
@@ -36,7 +36,8 @@ private:
 public:
   PackageDetails(Package& package);
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 };
